Description Usage Format Source
A dataset from the online experiment in the paper "Choice and personal responsibility: What is a morally relevant choice?" by Alexander W. Cappelen, Sebastian Fest, Erik Ø. Sørensen, and Bertil Tungodden.
1 |
A data frame with 7124 observations and 22 variables:
Non-informative identifier of individual participant
Did the person complete the experiment (1: yes, 2: no)
Treatment name (characters)
Treatment names as from kantar (characters)
Grouping of treatments into "Base", "Forced Choice" and "Nominal Choice")
Transfer to the unlucky (numeric)
Was there a work requirement in this treatment? (logical)
Indicator for treatment mapping 1:1 to lab experiment (logical)
Indicator for treatment being in lab experiment, but possibly without a work requirement (logical)
First cognitive reflection question (0/1)
Second cognitive reflection question (0/1)
Third cognitive reflection question (0/1)
Cognitive reflection score (0-3)
First understanding question, characters ("Ja" (yes), "Nei" (no), "Vet ikke" (don't know))
Second understanding question, characters
Age in years (numeric)
Gender, characters ("Kvinne": female, "Mann": male)
Education (characters)
Primary school
Vocational
High school
Some university / college
University / college
Individual income bracket (characters)
Occupation (characters)
Vote in last election
"Rødt" ("Red", far left)
"Sosialistisk Venstreparti" ("socialist left")
"Arbeiderpartiet" ("Labour")
"Miljøpartiet De Grønne" ("Environmental Green Party")
"Senterpartiet" ("Center party" (farm and rural party))
"Kristelig Folkeparti" ("Christian democrats", centrist)
"Kystpartiet" ("Coast party")
"Venstre" ("Left", European liberal party, centrist )
"Høyre" ("Right", conservative party)
"Fremskrittspartiet" ("Progress party", right-populist party)
"Some other party"
"Don't want to report"
"Did not vote"
"Did not have a right to vote"
"Don't remember/don't know"
Code for not voting to the right (logical, recode of "stortingsvalg")
Experiment conducted by the authors of the paper.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.